==> duckdb_0.3.2.tar.gz: duckdb/src/duckdb/amalgamation-12.cpp <==
#include "src/optimizer/statistics/operator/propagate_projection.cpp"

#include "src/optimizer/statistics/operator/propagate_set_operation.cpp"

#include "src/optimizer/statistics/operator/propagate_window.cpp"

#include "src/optimizer/statistics_propagator.cpp"

#include "src/optimizer/topn_optimizer.cpp"

#include "src/parallel/event.cpp"

#include "src/parallel/executor.cpp"

#include "src/parallel/executor_task.cpp"

#include "src/parallel/pipeline.cpp"

#include "src/parallel/pipeline_complete_event.cpp"

#include "src/parallel/pipeline_event.cpp"

#include "src/parallel/pipeline_executor.cpp"

#include "src/parallel/pipeline_finish_event.cpp"

#include "src/parallel/task_scheduler.cpp"

#include "src/parallel/thread_context.cpp"

#include "src/parser/base_expression.cpp"

#include "src/parser/column_definition.cpp"

#include "src/parser/constraint.cpp"

#include "src/parser/constraints/check_constraint.cpp"

#include "src/parser/constraints/not_null_constraint.cpp"

#include "src/parser/constraints/unique_constraint.cpp"

#include "src/parser/expression/between_expression.cpp"

#include "src/parser/expression/case_expression.cpp"

#include "src/parser/expression/cast_expression.cpp"

#include "src/parser/expression/collate_expression.cpp"

#include "src/parser/expression/columnref_expression.cpp"

#include "src/parser/expression/comparison_expression.cpp"

#include "src/parser/expression/conjunction_expression.cpp"

#include "src/parser/expression/constant_expression.cpp"

#include "src/parser/expression/default_expression.cpp"

#include "src/parser/expression/function_expression.cpp"

#include "src/parser/expression/lambda_expression.cpp"

#include "src/parser/expression/operator_expression.cpp"

#include "src/parser/expression/parameter_expression.cpp"

#include "src/parser/expression/positional_reference_expression.cpp"

#include "src/parser/expression/star_expression.cpp"

#include "src/parser/expression/subquery_expression.cpp"

#include "src/parser/expression/window_expression.cpp"

#include "src/parser/expression_util.cpp"

#include "src/parser/keyword_helper.cpp"

#include "src/parser/parsed_data/alter_table_info.cpp"

#include "src/parser/parsed_data/sample_options.cpp"

#include "src/parser/parsed_expression.cpp"

#include "src/parser/parsed_expression_iterator.cpp"

#include "src/parser/parser.cpp"

#include "src/parser/query_error_context.cpp"

==> duckdb_0.3.4-1.tar.gz: duckdb/src/duckdb/amalgamation-12.cpp <==
#include "src/optimizer/statistics/operator/propagate_get.cpp"

#include "src/optimizer/statistics/operator/propagate_join.cpp"

#include "src/optimizer/statistics/operator/propagate_limit.cpp"

#include "src/optimizer/statistics/operator/propagate_order.cpp"

#include "src/optimizer/statistics/operator/propagate_projection.cpp"

#include "src/optimizer/statistics/operator/propagate_set_operation.cpp"

#include "src/optimizer/statistics/operator/propagate_window.cpp"

#include "src/optimizer/statistics_propagator.cpp"

#include "src/optimizer/topn_optimizer.cpp"

#include "src/parallel/event.cpp"

#include "src/parallel/executor.cpp"

#include "src/parallel/executor_task.cpp"

#include "src/parallel/pipeline.cpp"

#include "src/parallel/pipeline_complete_event.cpp"

#include "src/parallel/pipeline_event.cpp"

#include "src/parallel/pipeline_executor.cpp"

#include "src/parallel/pipeline_finish_event.cpp"

#include "src/parallel/task_scheduler.cpp"

#include "src/parallel/thread_context.cpp"

#include "src/parser/base_expression.cpp"

#include "src/parser/column_definition.cpp"

#include "src/parser/constraint.cpp"

#include "src/parser/constraints/check_constraint.cpp"

#include "src/parser/constraints/foreign_key_constraint.cpp"

#include "src/parser/constraints/not_null_constraint.cpp"

#include "src/parser/constraints/unique_constraint.cpp"

#include "src/parser/expression/between_expression.cpp"

#include "src/parser/expression/case_expression.cpp"

#include "src/parser/expression/cast_expression.cpp"

#include "src/parser/expression/collate_expression.cpp"

#include "src/parser/expression/columnref_expression.cpp"

#include "src/parser/expression/comparison_expression.cpp"

#include "src/parser/expression/conjunction_expression.cpp"

#include "src/parser/expression/constant_expression.cpp"

#include "src/parser/expression/default_expression.cpp"

#include "src/parser/expression/function_expression.cpp"

#include "src/parser/expression/lambda_expression.cpp"

#include "src/parser/expression/operator_expression.cpp"

#include "src/parser/expression/parameter_expression.cpp"

#include "src/parser/expression/positional_reference_expression.cpp"

#include "src/parser/expression/star_expression.cpp"

#include "src/parser/expression/subquery_expression.cpp"

#include "src/parser/expression/window_expression.cpp"

#include "src/parser/expression_util.cpp"

#include "src/parser/keyword_helper.cpp"

#include "src/parser/parsed_data/alter_table_info.cpp"

#include "src/parser/parsed_data/sample_options.cpp"
